==> netbeans_8.0.2%2Bdfsg1.orig.tar.xz: netbeans-8.0.2/php.dbgp/src/org/netbeans/modules/php/dbgp/packets/Stack.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */
package org.netbeans.modules.php.dbgp.packets;

import org.w3c.dom.Node;

/**
 * @author ads
 *
 */
public class Stack extends Input {
    private static final String INPUT = "input"; // NOI18N
    private static final String CMDEND = "cmdend"; // NOI18N
    private static final String CMDBEGIN = "cmdbegin"; // NOI18N
    private static final String WHERE = "where"; // NOI18N

    public enum Type {
        FILE,
        EVAL,
        QUEST;

        @Override
        public String toString() {
            if (this != QUEST) {
                return super.toString().toLowerCase();
            } else {
                return "?"; // NOI18N
            }
        }

        public static Type forString(String str) {
            Type[] types = Type.values();
            for (Type type : types) {
                if (type.toString().equals(str)) {
                    return type;
                }
            }
            return null;
        }

    }

    Stack(Node node) {
        super(node);
    }

    public String getCurrentCommandName() {
        return getAttribute(WHERE);
    }

    public Position getCurrentInstructionStart() {
        return getPosition(CMDBEGIN);
    }

    public Position getCurrentInstructionEnd() {
        return getPosition(CMDEND);
    }

    public Input getInput() {
        Node node = getChild(INPUT);
        if (node == null) {
            return null;
        }
        return new Input(node);
    }

    private Position getPosition(String attrName) {
        String value = getAttribute(attrName);
        if (value == null) {
            return null;
        }
        String[] values = value.split(":"); //NOI18N
        assert values.length == 2;
        return new Position(values[0], values[1]);
    }

    public static final class Position {
        private int myLine;
        private int myOffset;

        private Position(String line, String offset) {
            try {
                myLine = Integer.parseInt(line);
                myOffset = Integer.parseInt(offset);
            } catch (NumberFormatException e) {
                myLine = -1;
                myOffset = -1;
            }
        }

        public int getLine() {
            return myLine;
        }

        public int getOffset() {
            return myOffset;
        }

    }

}

==> netbeans_8.2%2Bdfsg1.orig.tar.xz: netbeans-8.2/php.dbgp/src/org/netbeans/modules/php/dbgp/packets/Stack.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */
package org.netbeans.modules.php.dbgp.packets;

import java.util.Locale;
import org.w3c.dom.Node;

/**
 * @author ads
 *
 */
public class Stack extends Input {
    private static final String INPUT = "input"; // NOI18N
    private static final String CMDEND = "cmdend"; // NOI18N
    private static final String CMDBEGIN = "cmdbegin"; // NOI18N
    private static final String WHERE = "where"; // NOI18N

    public enum Type {
        FILE,
        EVAL,
        QUEST;

        @Override
        public String toString() {
            if (this != QUEST) {
                return super.toString().toLowerCase(Locale.US);
            } else {
                return "?"; // NOI18N
            }
        }

        public static Type forString(String str) {
            Type[] types = Type.values();
            for (Type type : types) {
                if (type.toString().equals(str)) {
                    return type;
                }
            }
            return null;
        }

    }

    Stack(Node node) {
        super(node);
    }

    public String getCurrentCommandName() {
        return getAttribute(WHERE);
    }

    public Position getCurrentInstructionStart() {
        return getPosition(CMDBEGIN);
    }

    public Position getCurrentInstructionEnd() {
        return getPosition(CMDEND);
    }

    public Input getInput() {
        Node node = getChild(INPUT);
        if (node == null) {
            return null;
        }
        return new Input(node);
    }

    private Position getPosition(String attrName) {
        String value = getAttribute(attrName);
        if (value == null) {
            return null;
        }
        String[] values = value.split(":"); //NOI18N
        assert values.length == 2;
        return new Position(values[0], values[1]);
    }

    public static final class Position {
        private int myLine;
        private int myOffset;

        private Position(String line, String offset) {
            try {
                myLine = Integer.parseInt(line);
                myOffset = Integer.parseInt(offset);
            } catch (NumberFormatException e) {
                myLine = -1;
                myOffset = -1;
            }
        }

        public int getLine() {
            return myLine;
        }

        public int getOffset() {
            return myOffset;
        }

    }

}
